# Modules of GenET

GenET is a library that provides functions for genome editing and other biological research.

### analysis


### database


### design


### models


### predict


### utils






